summaryrefslogtreecommitdiffstats
path: root/konq-plugins/fsview/treemap.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:45:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:45:00 -0600
commitca82971624269719d487c6f7980d7237f9420036 (patch)
treecac461d765c50b2709a9ef6324940e70fe056ba2 /konq-plugins/fsview/treemap.h
parent0e4ea21f450acbb4ea3c5a1293341668494d7dd4 (diff)
downloadtdeaddons-ca82971624269719d487c6f7980d7237f9420036.tar.gz
tdeaddons-ca82971624269719d487c6f7980d7237f9420036.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'konq-plugins/fsview/treemap.h')
-rw-r--r--konq-plugins/fsview/treemap.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/konq-plugins/fsview/treemap.h b/konq-plugins/fsview/treemap.h
index 0aa5a9d..9bacedc 100644
--- a/konq-plugins/fsview/treemap.h
+++ b/konq-plugins/fsview/treemap.h
@@ -215,7 +215,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
*
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
* items on demand, reimplement tqchildren().
*/
class TreeMapItem: public StoredDrawParams
{
@@ -250,7 +250,7 @@ public:
// force a redraw of this item
void redraw();
// delete all tqchildren
void clear();
// force new child generation & refresh
@@ -290,7 +290,7 @@ public:
*/
void setItemRect(const TQRect& r) { _rect = r; }
void clearItemRect();
- const TQRect& tqitemRect() const { return _rect; }
+ const TQRect& itemRect() const { return _rect; }
int width() const { return _rect.width(); }
int height() const { return _rect.height(); }
@@ -343,7 +343,7 @@ public:
* For value() sorting, use <textNo> = -2
*
* For fast sorting, set this to -1 before child insertions and call
* again after inserting all tqchildren.
*/
void setSorting(int textNo, bool ascending = true);
@@ -351,18 +351,18 @@ public:
* Resort according to the already set sorting.
*
* This has to be done if the sorting base changes (e.g. text or values
* change). If this is only true for the tqchildren of this item, you can
* set the recursive parameter to false.
*/
void resort(bool recursive = true);
virtual SplitMode splitMode() const;
virtual int rtti() const;
- // not const as this can create tqchildren on demand
- virtual TreeMapItemList* tqchildren();
+ // not const as this can create children on demand
+ virtual TreeMapItemList* children();
protected:
- TreeMapItemList* _tqchildren;
+ TreeMapItemList* _children;
double _sum, _value;
private:
@@ -372,7 +372,7 @@ private:
int _sortTextNo;
bool _sortAscending;
- // temporary tqlayout
+ // temporary layout
TQRect _rect;
TQPtrList<TQRect>* _freeRects;
int _depth;
@@ -436,7 +436,7 @@ public:
/**
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
* has no selected tqchildren or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -452,7 +452,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
* Clear selection of all selected items which are tqchildren of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
*/
@@ -464,7 +464,7 @@ public:
* Range means for a hierarchical widget:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
* range of direct tqchildren between but excluding the child
* leading to i1 and the child leading to i2.
*/
void setRangeSelection(TreeMapItem* i1,
@@ -517,7 +517,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
* If a tqchildren value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
* parent/child size relation can not be mapped to a correct
@@ -629,7 +629,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
* Redraws an item with all tqchildren.
* This takes changed values(), sums(), colors() and text() into account.
*/
void redraw(TreeMapItem*);
@@ -215,7 +215,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
- * items on demand, reimplement tqchildren().
+ * items on demand, reimplement children().
*/
class TreeMapItem: public StoredDrawParams
@@ -250,7 +250,7 @@ public:
// force a redraw of this item
void redraw();
- // delete all tqchildren
+ // delete all children
void clear();
// force new child generation & refresh
@@ -343,7 +343,7 @@ public:
*
* For fast sorting, set this to -1 before child insertions and call
- * again after inserting all tqchildren.
+ * again after inserting all children.
*/
void setSorting(int textNo, bool ascending = true);
@@ -351,18 +351,18 @@ public:
*
* This has to be done if the sorting base changes (e.g. text or values
- * change). If this is only true for the tqchildren of this item, you can
+ * change). If this is only true for the children of this item, you can
* set the recursive parameter to false.
*/
@@ -436,7 +436,7 @@ public:
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
- * has no selected tqchildren or parents stays true.
+ * has no selected children or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -452,7 +452,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
- * Clear selection of all selected items which are tqchildren of
+ * Clear selection of all selected items which are children of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
@@ -464,7 +464,7 @@ public:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
- * range of direct tqchildren between but excluding the child
+ * range of direct children between but excluding the child
* leading to i1 and the child leading to i2.
*/
@@ -517,7 +517,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
- * If a tqchildren value() is almost the parents sum(),
+ * If a children value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
@@ -629,7 +629,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
- * Redraws an item with all tqchildren.
+ * Redraws an item with all children.
* This takes changed values(), sums(), colors() and text() into account.
*/